@@ -358,6 +358,7 @@ pub(crate) fn sendmsg_unix(
 #[cfg(not(any(
     apple,
     windows,
+    target_os = "aix",
     target_os = "espidf",
     target_os = "haiku",
     target_os = "redox",
@@ -396,6 +397,7 @@ pub(crate) fn acceptfrom(sockfd: BorrowedFd<'_>) -> io::Result<(OwnedFd, Option<
 #[cfg(not(any(
     apple,
     windows,
+    target_os = "aix",
     target_os = "espidf",
     target_os = "haiku",
     target_os = "nto",
@@ -427,6 +429,7 @@ pub(crate) fn acceptfrom_with(
 #[cfg(any(
     apple,
     windows,
+    target_os = "aix",
     target_os = "espidf",
     target_os = "haiku",
     target_os = "nto"
@@ -440,6 +443,7 @@ pub(crate) fn accept_with(sockfd: BorrowedFd<'_>, _flags: SocketFlags) -> io::Re
 #[cfg(any(
     apple,
     windows,
+    target_os = "aix",
     target_os = "espidf",
     target_os = "haiku",
     target_os = "nto"
@@ -517,6 +521,19 @@ pub(crate) mod sockopt {
     use super::{c, in6_addr_new, in_addr_new, BorrowedFd};
     use crate::io;
     use crate::net::sockopt::Timeout;
+    #[cfg(not(any(
+        apple,
+        solarish,
+        windows,
+        target_os = "dragonfly",
+        target_os = "emscripten",
+        target_os = "espidf",
+        target_os = "haiku",
+        target_os = "netbsd",
+        target_os = "nto",
+        target_os = "openbsd"
+    )))]
+    use crate::net::AddressFamily;
     use crate::net::{Ipv4Addr, Ipv6Addr, SocketType};
     use crate::utils::as_mut_ptr;
     use core::time::Duration;
@@ -809,6 +826,27 @@ pub(crate) mod sockopt {
         getsockopt(fd, c::SOL_SOCKET as _, c::SO_SNDBUF).map(|size: u32| size as usize)
     }
 
+    #[inline]
+    #[cfg(not(any(
+        apple,
+        solarish,
+        windows,
+        target_os = "aix",
+        target_os = "dragonfly",
+        target_os = "emscripten",
+        target_os = "espidf",
+        target_os = "haiku",
+        target_os = "netbsd",
+        target_os = "nto",
+        target_os = "openbsd"
+    )))]
+    pub(crate) fn get_socket_domain(fd: BorrowedFd<'_>) -> io::Result<AddressFamily> {
+        let domain: c::c_int = getsockopt(fd, c::SOL_SOCKET as _, c::SO_DOMAIN)?;
+        Ok(AddressFamily(
+            domain.try_into().map_err(|_| io::Errno::OPNOTSUPP)?,
+        ))
+    }
+
     #[inline]
     pub(crate) fn set_ip_ttl(fd: BorrowedFd<'_>, ttl: u32) -> io::Result<()> {
         setsockopt(fd, c::IPPROTO_IP as _, c::IP_TTL, ttl)
